// @ts-ignore
import {html, LitElement} from 'lit';
// @ts-ignore
import {customElement} from 'lit/decorators.js';
import {JmixBpmIncomingEvent} from "./component/types";
import BpmModeler from "./bpm/BpmModeler";
import selectionChangedEventHandler from "./component/selectionChangedEventHandler";
import schemaChangedEventHandler from "./component/schemaChangedEventHandler";

@customElement('jmix-bpmn-modeler')
class JmixBpmModeler extends LitElement {
    private readonly BPM_CONTAINER_HOLDER: string = "bpmnContainer";

    private readonly modeler: BpmModeler;
    private changed: boolean = false;
    private bpmnXml?: string;
    private bpmModeling: any;
    private $server: any;

    constructor() {
        super();
        this.modeler = new BpmModeler();
        this.bpmModeling = this.modeler.get('bpmModeling');
    }

    static get properties() {
        return {
            bpmnXml: {type: String}
        }
    }

    public reloadSchema(xmlSchema: string) {
        this.modeler.importXML(xmlSchema!).then(r => {
            console.log(r.warnings);
        });
    }

    // @ts-ignore
    public async getXmlSchema(): Promise<string> {
        const requestXml = await this.modeler.saveXML({
            format: true
        });
        return requestXml.xml!;
    }

    render() {
        try {
            this.initModeler();
        } catch (err) {
            console.log('error rendering', err);
        }

        let modeler = this.modeler as any;
        const canvas = modeler.get("canvas");
        const element = this;

        modeler.on('element.changed', e => schemaChangedEventHandler(element, modeler));
        modeler.on("selection.changed", e => selectionChangedEventHandler(element, canvas.getRootElement(), e as JmixBpmIncomingEvent));
        modeler.on('commandStack.changed', e => {
            if (!this.changed) {
                this.changed = true;
                this.$server.setHasChanged(this.changed);
            }
        })

        return html`
            <div/>
        `;
    }

    public updateElementProperties(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.updateElementProperties(cmd.elementId, cmd.elementProperties);
    };

    public createOrUpdateNestedObject(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createOrUpdateNestedObject(
            cmd.elementId,
            cmd.nestedPropertyName,
            cmd.nestedElementType,
            cmd.objectProperties
        );
    };

    public createOrUpdateFormData(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createOrUpdateFormData(cmd.elementId, cmd.formDataDTO);
    }

    public createOrUpdateExtensionElement(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createOrUpdateExtensionElement(cmd);
    }

    public setMultiInstanceFormalExpression(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.setMultiInstanceFormalExpression(cmd.elementId, cmd.propertyName, cmd.propertyValue);
    }

    public updateTimerEventDefinition(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.updateTimerEventDefinition(cmd.elementId, cmd.timerDefinitionType, cmd.value);
    }

    public updateEventDefinitionProperties(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.updateEventDefinitionProperties(cmd);
    }

    public updateEventDefinition(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.updateEventDefinition(cmd);
    }

    public createOrUpdateRootElement(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createOrUpdateRootElement(this.modeler.getDefinitions(), cmd.elementId, cmd.elementType, cmd.objectProperties);
    }

    public removeRootElement(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.removeRootElement(this.modeler.getDefinitions(), cmd.elementId, cmd.elementType);
    }

    public createOrUpdateSpringBean(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createOrUpdateSpringBean(cmd);
    }

    public removeSpringBean(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.removeSpringBean(cmd);
    }

    public removeExtensionElements(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.removeExtensionElements(cmd);
    }

    public createOrUpdateProcessVariable(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createOrUpdateProcessVariable(cmd.elementId, cmd.variableName, cmd.processVariableDTO);
    }

    public removeProcessVariable(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.removeProcessVariable(cmd);
    }

    public createOrUpdateExtensionProperty(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createOrUpdateExtensionProperty(cmd);
    }

    public removeExtensionProperty(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.removeExtensionProperty(cmd);
    }

    public createAndSetListProperty(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createAndSetListProperty(cmd);
    }

    public updateProcessDocumentation(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.updateProcessDocumentation(cmd);
    }

    public createListener(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createListener(cmd);
    }

    public removeParticipantProcessExtensionElements(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.removeParticipantProcessExtensionElements(cmd.elementId, cmd.extensionElementType);
    }

    public createOrUpdateParticipantProcessExtensionElement(cmdJson: any) {
        const cmd = JSON.parse(cmdJson);
        this.bpmModeling.createOrUpdateParticipantProcessExtensionElement(cmd);
    }

    private initModeler() {
        // @ts-ignore
        this.modeler.attachTo(document.getElementById(this.BPM_CONTAINER_HOLDER)!);
        if (this.bpmnXml) {
            this.modeler.importXML(this.bpmnXml).catch(e => {
                console.error(e);
            });
        }
    }
}



