// @ts-ignore
import {ModdleElement} from "bpmn-js/lib/BaseViewer";
// @ts-ignore
import {Event as InternalEvent} from 'diagram-js/lib/core/EventBus';

export type JmixBpmIncomingEvent = {
    newSelection: JmixBpmnElement[]
    oldSelection: JmixBpmnElement[]
    type: string | undefined | null
} & InternalEvent;

export type JmixBpmnElement = Shape | Connection | Label | undefined;

export enum ShapeType {
    dnm = "dmn",
    jmixLoadEntitiesJpql = "jmix-load-entities-jpql",
    jmixModifyEntity = "jmix-modify-entity",
    jmixCreateEntity = "jmix-create-entity",
    jmixSendEmail = "jmix-send-email",

    bpmnStartEvent = "bpmn:StartEvent",
    bpmnIntermediateCatchEvent = "bpmn:IntermediateCatchEvent",
    bpmnIntermediateThrowEvent = "bpmn:IntermediateThrowEvent",
    bpmnEndEvent = "bpmn:EndEvent",

    bpmnExclusiveGateway = "bpmn:ExclusiveGateway",
    bpmnParallelGateway = "bpmn:ParallelGateway",
    bpmnInclusiveGateway = "bpmn:InclusiveGateway",
    bpmnComplexGateway = "bpmn:ComplexGateway",
    bpmnEventBasedGateway = "bpmn:EventBasedGateway",

    bpmnTask = "bpmn:Task",
    bpmnUserTask = "bpmn:UserTask",
    bpmnServiceTask = "bpmn:ServiceTask",
    bpmnSendTask = "bpmn:SendTask",
    bpmnReceiveTask = "bpmn:ReceiveTask",
    bpmnManualTask = "bpmn:ManualTask",
    bpmnBusinessRuleTask = "bpmn:BusinessRuleTask",
    bpmnScriptTask = "bpmn:ScriptTask",
    bpmnCallActivity = "bpmn:CallActivity",

    bpmnSubProcess = "bpmn:SubProcess",
    bpmnTransaction = "bpmn:Transaction",

    bpmnDataObjectReference = "bpmn:DataObjectReference",
    bpmnDataStoreReference = "bpmn:DataStoreReference",

    bpmnParticipant = "bpmn:Participant",
    bpmnGroup = "bpmn:Group"
}

/*
bpmnSubProcess + collapsed == CollapsedSubProcess
bpmnSubProcess.businessObject.triggeredByEvent=true == EventSubProcess
 */

export enum EventDefinition {
    bpmnMessageEventDefinition = 'bpmn:MessageEventDefinition',
    bpmnTimerEventDefinition = "bpmn:TimerEventDefinition",
    bpmnConditionalEventDefinition = "bpmn:ConditionalEventDefinition",
    bpmnSignalEventDefinition = "bpmn:SignalEventDefinition",
    bpmnEscalationEventDefinition = "bpmn:EscalationEventDefinition",
    bpmnLinkEventDefinition = "bpmn:LinkEventDefinition",
    bpmnCompensateEventDefinition = "bpmn:CompensateEventDefinition",
    bpmnTerminateEventDefinition = "bpmn:TerminateEventDefinition",
    bpmnErrorEventDefinition = "bpmn:ErrorEventDefinition",
    bpmnCancelEventDefinition = "bpmn:CancelEventDefinition"
}

const typeDefinitionMapping: { [key in ShapeType]?: EventDefinition[] } = {
    [ShapeType.bpmnStartEvent]: [
        EventDefinition.bpmnMessageEventDefinition,
        EventDefinition.bpmnTimerEventDefinition,
        EventDefinition.bpmnConditionalEventDefinition,
        EventDefinition.bpmnSignalEventDefinition
    ],
    [ShapeType.bpmnIntermediateThrowEvent]: [
        EventDefinition.bpmnMessageEventDefinition,
        EventDefinition.bpmnEscalationEventDefinition,
        EventDefinition.bpmnLinkEventDefinition,
        EventDefinition.bpmnCompensateEventDefinition,
        EventDefinition.bpmnSignalEventDefinition
    ],
    [ShapeType.bpmnIntermediateCatchEvent]: [
        EventDefinition.bpmnMessageEventDefinition,
        EventDefinition.bpmnTimerEventDefinition,
        EventDefinition.bpmnConditionalEventDefinition,
        EventDefinition.bpmnLinkEventDefinition,
        EventDefinition.bpmnSignalEventDefinition
    ],
    [ShapeType.bpmnEndEvent]: [
        EventDefinition.bpmnMessageEventDefinition,
        EventDefinition.bpmnEscalationEventDefinition,
        EventDefinition.bpmnErrorEventDefinition,
        EventDefinition.bpmnCancelEventDefinition,
        EventDefinition.bpmnCompensateEventDefinition,
        EventDefinition.bpmnSignalEventDefinition,
        EventDefinition.bpmnTerminateEventDefinition
    ]
}


export type Shape = {
    default: any;
    children?: JmixBpmnElement[];
    collapsed: boolean;
    di?: any;
    height: number;
    hidden: boolean;
    id: string;
    isFrame: boolean;
    labels: [];
    type: ShapeType | undefined;
    width: number;
    x: number;
    y: number;
    attachers: []
    businessObject?: any;
    host?: any;
    incoming?: Connection[];
    outgoing?: Connection[];
    parent?: JmixBpmnElement;
    order?: { level: number }
};

type BusinessObject = {
    "$type"?: string;
    "default"?: any;
    flowElements?: JmixBpmnElement[]
    id: string;
    name?: string;
    triggeredByEvent?: boolean;
    "$attrs"?: Object;
    "$parent"?: JmixBpmnElement;
    lanes: ModdleElement[]
}

export type Connection = {
    di?: ModdleElement;
    height: number;
    id: string;
    labels: [];
};

export type Label = {
    children?: JmixBpmnElement[];
    di?: ModdleElement;
    height: number;
    hidden: boolean;
    id: string;
    labels: [];
    type: ShapeType | undefined;
    width: number;
    x: number;
    y: number;
    attachers: []
    businessObjects?: ModdleElement;
    host?: any;
    incoming?: Connection[];
    outgoing?: Connection[];
    label?: string;
    labelTarget?: JmixBpmnElement;
    parent?: JmixBpmnElement;
};

export type  SpringBeanData = {
    rawExpression: string;
    beanName: string;
    methodName: string;
    methodParams: SpringBeanMethodParam[];
};

export type SpringBeanMethodParam = {
    isVariable: boolean;
    name: string;
    type: string;
    javaType: string;
    value: string;
}

export type FormParameterData = {
    businessId: string;
    type: string;
    caption?: string;
    editable?: boolean;
    required?: boolean;
}

export type FormOutcomeData = {
    businessId: string;
    caption?: string;
    icon?: string;
}